window.Gleam.initSearch([{"doc":"zipnotic","title":"zipnotic","content":"# zipnotic\n\n[![Package Version](https://img.shields.io/hexpm/v/zipnotic)](https://hex.pm/packages/zipnotic)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/zipnotic/)\n\nA grab bag of zip functions.\n\n## Installation\n\n```sh\ngleam add zipnotic@1\n```\n\n## Usage\n\n```gleam\nimport gleam/io\nimport zipnotic\n\npub fn main() {\n  zipnotic.zip_longest_2([1], [&quot;a&quot;, &quot;b&quot;]) |&gt; io.debug\n  // [#(Some(1), Some(&quot;a&quot;)), #(None, Some(&quot;b&quot;))]\n\n  zipnotic.zip_2([1, 2], [&quot;a&quot;]) |&gt; io.debug\n  // [#(1, &quot;a&quot;)]\n\n  zipnotic.strict_zip_2([1], [&quot;a&quot;]) |&gt; io.debug\n  // Ok([#(1, &quot;a&quot;)])\n\n  zipnotic.strict_zip_2([1, 2], [&quot;a&quot;]) |&gt; io.debug\n  // Error(Nil)\n\n  zipnotic.zip_longest_3([1], [&quot;a&quot;, &quot;b&quot;], [True]) |&gt; io.debug\n  // [#(Some(1), Some(&quot;a&quot;), Some(True)), #(None, Some(&quot;b&quot;), None)]\n\n  zipnotic.zip_3([1], [&quot;a&quot;, &quot;b&quot;], [1.0, 1.1]) |&gt; io.debug\n  // [#(1, &quot;a&quot;, 1.0)]\n\n  zipnotic.strict_zip_3([1], [&quot;a&quot;], [1.0]) |&gt; io.debug\n  // Ok([#(1, &quot;a&quot;, 1.0)])\n\n  zipnotic.strict_zip_3([1, 2], [&quot;a&quot;], [1.0]) |&gt; io.debug\n  // Error(Nil)\n\n  zipnotic.zip_longest_4([1], [&quot;a&quot;, &quot;b&quot;], [1.0], [True, False]) |&gt; io.debug\n  // [#(Some(1), Some(&quot;a&quot;), Some(1.0), Some(True)), #(None, Some(&quot;b&quot;), None, Some(False))]\n\n  zipnotic.zip_4([1], [&quot;a&quot;, &quot;b&quot;], [1.0], [True, False]) |&gt; io.debug\n  // [#(1, &quot;a&quot;, 1.0, True)]\n\n  zipnotic.strict_zip_4([1], [&quot;a&quot;], [1.0], [True]) |&gt; io.debug\n  // Ok([#(1, &quot;a&quot;, 1.0, True)])\n\n  zipnotic.strict_zip_4([1, 2], [&quot;a&quot;], [1.0], [True]) |&gt; io.debug\n  // Error(Nil)\n}\n```\n","url":"index.html"},{"doc":"zipnotic","title":"strict_zip_2","content":"pub fn strict_zip_2(\n  list: List(a),\n  other: List(b),\n) -&gt; Result(List(#(a, b)), Nil)\n Zips two lists into a result. If the lists are all equal in length, a list\n of tuples is returned within `Ok`. If the lists are not the same length,\n `Error(Nil)` is returned.\n\n strict_zip_2([1], [&quot;a&quot;]) -&gt; Ok([#(1, &quot;a&quot;)])\n strict_zip_2([1, 2], [&quot;a&quot;]) -&gt; Error(Nil)\nSynonyms:\nzipnotic.strict_zip_2\nzipnotic strict_zip_2","url":"zipnotic.html#strict_zip_2"},{"doc":"zipnotic","title":"strict_zip_3","content":"pub fn strict_zip_3(\n  list: List(a),\n  other_1: List(b),\n  other_2: List(c),\n) -&gt; Result(List(#(a, b, c)), Nil)\n Zips three lists into a result. If the lists are all equal in length, a list\n of tuples is returned within `Ok`. If the lists are not the same length,\n `Error(Nil)` is returned.\n\n strict_zip_3([1], [&quot;a&quot;], [1.0]) -&gt; Ok([#(1, &quot;a&quot;, 1.0)])\n strict_zip_3([1, 2], [&quot;a&quot;], [1.0]) -&gt; Error(Nil)\nSynonyms:\nzipnotic.strict_zip_3\nzipnotic strict_zip_3","url":"zipnotic.html#strict_zip_3"},{"doc":"zipnotic","title":"strict_zip_4","content":"pub fn strict_zip_4(\n  list: List(a),\n  other_1: List(b),\n  other_2: List(c),\n  other_3: List(d),\n) -&gt; Result(List(#(a, b, c, d)), Nil)\n Zips four lists into a result. If the lists are all equal in length, a list\n of tuples is returned within `Ok`. If the lists are not the same length,\n `Error(Nil)` is returned.\n\n strict_zip_4([1], [&quot;a&quot;], [1.0], [True]) -&gt; Ok([#(1, &quot;a&quot;, 1.0, True)])\n strict_zip_4([1, 2], [&quot;a&quot;], [1.0], [True]) -&gt; Error(Nil)\nSynonyms:\nzipnotic.strict_zip_4\nzipnotic strict_zip_4","url":"zipnotic.html#strict_zip_4"},{"doc":"zipnotic","title":"zip_2","content":"pub fn zip_2(list: List(a), other: List(b)) -&gt; List(#(a, b))\n Zips two lists into tuples of values. Zipping ends when the shortest list is\n exhausted.\n\n zip_2([1, 2], [&quot;a&quot;]) -&gt; [#(1, &quot;a&quot;)]\nSynonyms:\nzipnotic.zip_2\nzipnotic zip_2","url":"zipnotic.html#zip_2"},{"doc":"zipnotic","title":"zip_3","content":"pub fn zip_3(\n  list: List(a),\n  other_1: List(b),\n  other_2: List(c),\n) -&gt; List(#(a, b, c))\n Zips three lists into tuples of values. Zipping ends when the shortest list\n is exhausted.\n\n zip_3([1], [&quot;a&quot;, &quot;b&quot;], [1.0, 1.1]) -&gt; [#(1, &quot;a&quot;, 1.0)]\nSynonyms:\nzipnotic.zip_3\nzipnotic zip_3","url":"zipnotic.html#zip_3"},{"doc":"zipnotic","title":"zip_4","content":"pub fn zip_4(\n  list: List(a),\n  other_1: List(b),\n  other_2: List(c),\n  other_3: List(d),\n) -&gt; List(#(a, b, c, d))\n Zips four lists into tuples of values. Zipping ends when the shortest list\n is exhausted.\n\n zip_4([1], [&quot;a&quot;, &quot;b&quot;], [1.0], [True, False]) -&gt; [#(1, &quot;a&quot;, 1.0, True)]\nSynonyms:\nzipnotic.zip_4\nzipnotic zip_4","url":"zipnotic.html#zip_4"},{"doc":"zipnotic","title":"zip_longest_2","content":"pub fn zip_longest_2(\n  list: List(a),\n  other: List(b),\n) -&gt; List(#(Option(a), Option(b)))\n Zips two lists into tuples containing optional values. Zipping ends when all\n lists are exhausted.\n\n zip_longest_2([1], [&quot;a&quot;, &quot;b&quot;]) -&gt; [#(Some(1), Some(&quot;a&quot;)), #(None, Some(&quot;b&quot;))]\nSynonyms:\nzipnotic.zip_longest_2\nzipnotic zip_longest_2","url":"zipnotic.html#zip_longest_2"},{"doc":"zipnotic","title":"zip_longest_3","content":"pub fn zip_longest_3(\n  list: List(a),\n  other_1: List(b),\n  other_2: List(c),\n) -&gt; List(#(Option(a), Option(b), Option(c)))\n Zips three lists into tuples containing optional values. Zipping ends when\n all lists are exhausted.\n\n zip_longest_3([1], [&quot;a&quot;, &quot;b&quot;], [True]) -&gt; [#(Some(1), Some(&quot;a&quot;), Some(True)), #(None, Some(&quot;b&quot;), None)]\nSynonyms:\nzipnotic.zip_longest_3\nzipnotic zip_longest_3","url":"zipnotic.html#zip_longest_3"},{"doc":"zipnotic","title":"zip_longest_4","content":"pub fn zip_longest_4(\n  list: List(a),\n  other_1: List(b),\n  other_2: List(c),\n  other_3: List(d),\n) -&gt; List(#(Option(a), Option(b), Option(c), Option(d)))\n Zips four lists into tuples containing optional values. Zipping ends when\n all lists are exhausted.\n\n zip_longest_4([1], [&quot;a&quot;, &quot;b&quot;], [1.0], [True, False]) -&gt; [#(Some(1), Some(&quot;a&quot;), Some(1.0), Some(True)), #(None, Some(&quot;b&quot;), None, Some(False))]\nSynonyms:\nzipnotic.zip_longest_4\nzipnotic zip_longest_4","url":"zipnotic.html#zip_longest_4"},{"doc":"zipnotic","title":"zipnotic","content":"","url":"zipnotic.html"}]);